@@ -4,8 +4,10 @@ use tract_nnef::internal::*;
 mod macros;
 
 mod concat;
+mod deconv_delay;
 mod delay;
 mod pad;
+mod slice;
 
 pub use tract_nnef;
 pub use tract_nnef::tract_core;
@@ -16,8 +18,10 @@ pub mod prelude {
 }
 
 pub mod ops {
-    pub use super::delay::Delay;
+    pub use super::deconv_delay::DeconvDelay;
+    pub use super::delay::{ Delay, DelayState };
     pub use super::pad::PulsePad;
+    pub use super::slice::PulsedAxisSlice;
 }
 
 pub trait WithPulse {
